@@ -7,5 +7,5 @@ class ApiPedido(ApiClientBase):
     AUTENTICA_APLICACAO = True
 
     def alterar_situacao(self, loja_id, pedido_numero, situacao_id, por, **kwargs):
-        path = '/loja/{}/pedido/{}/situacao/{}/{}'.format(loja_id, pedido_numero, situacao_id, por)
+        path = '/loja/{}/order/{}/status/{}/{}'.format(loja_id, pedido_numero, situacao_id, por)
         return self.to_dict(path, method="put", meta=True, **kwargs)
