@@ -6,6 +6,10 @@ class ApiPlataforma(ApiClientBase):
     NOME = "API_PLATAFORMA"
     AUTENTICA_APLICACAO = True
 
+    def verificacao_alterar(self, conta_id, verificada):
+        path = '/contas/{}/verificada/{}/'.format(conta_id, verificada)
+        return self.to_dict(path, method="put", meta=True)
+
     def situacao_alterar(self, conta_id, situacao):
         path = '/contas/{}/situacao/{}/'.format(conta_id, situacao)
         return self.to_dict(path, method="put", meta=True)
